# comment out if not pre-release
#define prel beta1

# rel for bumping
%define rel 1

Name:		blueman
Summary:	GTK+ Bluetooth Manager
Version:	2.3.5
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	GPLv2+
Group:		Communications/Bluetooth
URL:		https://github.com/blueman-project/blueman/
Source0:	https://github.com/blueman-project/blueman/releases/download/%{version}%{?prel:.%prel}/blueman-%{version}%{?prel:.%prel}.tar.xz
BuildRequires:	git-core
BuildRequires:	pkgconfig(bluez)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gthread-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(libstartup-notification-1.0)
BuildRequires:	pkgconfig(pygobject-3.0)
BuildRequires:	pkgconfig(polkit-agent-1)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-cython
BuildRequires:	intltool
BuildRequires:	thunar
BuildRequires:	iproute2

Requires:	bluez >= 5.11
Requires:	python3-gobject3
Requires:	polkit-agent
Requires:	pulseaudio-module-bluetooth
Requires:	adwaita-icon-theme
Requires:	iproute2
Recommends:	%{name}-sendto = %{version}-%{release}
Recommends:	bluez-pin

%description
Blueman is designed to provide simple, yet effective means for
controlling BlueZ API and simplifying bluetooth tasks such as:

* Connecting to 3G/EDGE/GPRS via dial-up
* Connecting to/Creating bluetooth networks
* Connecting to input devices
* Connecting to audio devices
* Sending/Receiving/Browsing files via OBEX
* Pairing

%prep
%autosetup -p1 -n %{name}-%{version}%{?prel:.%prel} -Sgit_am

%build
export PYTHON=%{__python3}
export CYTHONEXEC=cython-3
export PATH="%{_sbindir}${PATH:+:$PATH}"
%configure \
    --enable-polkit \
    --disable-static \
    --enable-thunar-sendto \
    --enable-settings-integration \
    --disable-schemas-compile \
    --with-dhcp-config=%{_sysconfdir}/dhcpd.conf
%make_build

%install
%make_install

desktop-file-install --vendor="" \
  --add-category="GTK" \
  --add-category="HardwareSettings" \
  --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/%{name}-manager.desktop

desktop-file-install \
 --add-category="GTK;GNOME;" \
 --add-only-show-in="GNOME;XFCE;LXDE;X-Cinnamon;MATE" \
 --delete-original \
 --dir %{buildroot}%{_sysconfdir}/xdg/autostart %{buildroot}%{_sysconfdir}/xdg/autostart/%{name}.desktop

desktop-file-install \
 --delete-original     \
 --dir %{buildroot}%{_datadir}/applications  %{buildroot}%{_datadir}/applications/%{name}-adapters.desktop

find %{buildroot} -name '*.la' -delete

%find_lang %{name}

%post
%systemd_post blueman-mechanism.service
%systemd_user_post blueman-applet.service

%postun
%systemd_postun_with_restart blueman-mechanism.service

%preun
%systemd_preun blueman-mechanism.service
%systemd_user_preun blueman-applet.service

%files -f %{name}.lang
%doc CHANGELOG.md FAQ README.md COPYING
%{_sysconfdir}/xdg/autostart/blueman.desktop
%{_bindir}/blueman*
%{_datadir}/blueman/
%{_datadir}/applications/blueman-manager.desktop
%{_datadir}/applications/blueman-adapters.desktop
%{_datadir}/glib-2.0/schemas/org.blueman.gschema.xml
%{_datadir}/polkit-1/actions/org.blueman.policy
%{_datadir}/polkit-1/rules.d/blueman.rules
%{_datadir}/Thunar/sendto/thunar-sendto-blueman.desktop
%{_iconsdir}/hicolor/*/*/blueman*
%{_datadir}/dbus-1/services/org.blueman.*.service
%{_datadir}/dbus-1/system-services/org.blueman*.service
%{_datadir}/dbus-1/system.d/org.blueman.Mechanism.conf
%{_unitdir}/blueman-mechanism.service
%{_userunitdir}/blueman-applet.service
%{_userunitdir}/blueman-manager.service

%{_mandir}/man1/blueman*.1*
%{_libexecdir}/blueman-mechanism
%{_libexecdir}/blueman-rfcomm-watcher
%{python3_sitelib}/blueman/
%{python3_sitearch}/_blueman.so


%changelog
* Wed Dec 14 2022 daviddavid <daviddavid> 2.3.5-1.mga9
+ Revision: 1922521
- new version: 2.3.5

* Sat Oct 22 2022 ghibo <ghibo> 2.3.4-1.mga9
+ Revision: 1898398
- Update to release 2.3.4

* Fri Sep 16 2022 papoteur <papoteur> 2.3.2-1.mga9
+ Revision: 1889150
- new 2.3.2
- new 2.3.2

* Thu Jun 09 2022 wally <wally> 2.2.4-1.mga9
+ Revision: 1863772
- new version 2.2.4

* Tue Apr 05 2022 umeabot <umeabot> 2.2.3-3.mga9
+ Revision: 1844789
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 2.2.3-2.mga9
+ Revision: 1774426
- rebuild for python-3.10

* Sun Jan 09 2022 wally <wally> 2.2.3-1.mga9
+ Revision: 1767333
- new version 2.2.3
- drop old obsoletes

* Sun Aug 08 2021 wally <wally> 2.2.2-1.mga9
+ Revision: 1740458
- new version 2.2.2

* Mon Mar 15 2021 wally <wally> 2.1.4-2.mga9
+ Revision: 1703648
- rebuild for python 3.9

* Fri Oct 30 2020 daviddavid <daviddavid> 2.1.4-1.mga8
+ Revision: 1640598
- new version: 2.1.4, fixes CVE-2020-15238 (mga#27485)

* Tue Aug 04 2020 wally <wally> 2.1.3-2.mga8
+ Revision: 1610937
- add patch to port to Ayatana AppIndicator

* Sun May 10 2020 daviddavid <daviddavid> 2.1.3-1.mga8
+ Revision: 1582693
- new version: 2.1.3

* Wed Feb 19 2020 umeabot <umeabot> 2.1.2-2.mga8
+ Revision: 1544541
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 daviddavid <daviddavid> 2.1.2-1.mga8
+ Revision: 1483216
- new version: 2.1.2
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 08 2019 wally <wally> 2.1.1-2.mga8
+ Revision: 1438386
- rebuild for python3.8

* Sat Jul 13 2019 daviddavid <daviddavid> 2.1.1-1.mga8
+ Revision: 1420857
- new version: 2.1.1

* Sat Jun 29 2019 wally <wally> 2.1-1.mga8
+ Revision: 1416091
- new version 2.1

* Mon May 13 2019 wally <wally> 2.1-0.beta1.1.mga7
+ Revision: 1397648
- new version 2.1.beta1
- drop upstreamed patches
- drop unneeded python3-dbus req

* Sun Feb 24 2019 wally <wally> 2.1-0.alpha3.1.mga7
+ Revision: 1369971
- new version 2.1.alpha3 with patches from upstream

* Mon Feb 04 2019 wally <wally> 2.0.8-2.mga7
+ Revision: 1363068
- enable thunar sendto again

* Mon Feb 04 2019 wally <wally> 2.0.8-1.mga7
+ Revision: 1363060
- new version 2.0.8
- build with python3
- add default polkit rules file that allows users in group wheel to perform administrative actions
- disable thunar sendto

* Thu Oct 25 2018 bcornec <bcornec> 2.0.6-1.mga7
+ Revision: 1325145
- update to upstream 2.0.6

* Fri Sep 21 2018 umeabot <umeabot> 2.0.5-2.mga7
+ Revision: 1295552
- Mageia 7 Mass Rebuild

* Thu Dec 14 2017 tarakbumba <tarakbumba> 2.0.5-1.mga7
+ Revision: 1182612
- Updated to 2.0.5 version

* Sat Apr 02 2016 tarakbumba <tarakbumba> 2.0.4-1.mga6
+ Revision: 997699
- Update to 2.0.4 version

* Sat Mar 19 2016 luigiwalser <luigiwalser> 2.0.3-2.mga6
+ Revision: 993011
- fix patch

* Fri Dec 18 2015 tarakbumba <tarakbumba> 2.0.3-1.mga6
+ Revision: 911766
- Update to 2.0.3 version

* Thu Dec 17 2015 tarakbumba <tarakbumba> 2.0.2-1.mga6
+ Revision: 911503
- Update to 2.0.2 version

* Fri Nov 27 2015 tarakbumba <tarakbumba> 2.0.1-4.mga6
+ Revision: 906369
- Rebuild with python2

* Thu Nov 26 2015 tarakbumba <tarakbumba> 2.0.1-3.mga6
+ Revision: 906341
- Fix python3 build and requires
- Fix shabangs for python2 build

* Sun Nov 08 2015 tarakbumba <tarakbumba> 2.0.1-2.mga6
+ Revision: 899259
- Require mate-icon-theme otherwise it does not pull one

* Sat Oct 10 2015 tarakbumba <tarakbumba> 2.0.1-1.mga6
+ Revision: 889409
- Update to 2.0.1 bugfix release
+ doktor5000 <doktor5000>
- include polkit policy
- fixed conditional macro handling of %%{pre_release} and %%snap

* Tue Jun 23 2015 tarakbumba <tarakbumba> 2.0-1.mga6
+ Revision: 841434
- Update to stable 2.0 version
- Add upstream patches from git
- Enable polkit support
- Add missing pulseaudio-module-bluetooth dependency

* Mon May 18 2015 tmb <tmb> 1.99.alpha3-0.git20150512.2.mga5
+ Revision: 822352
- submit to /release

* Wed May 13 2015 tarakbumba <tarakbumba> 1.99.alpha3-0.git20150512.1.mga5
+ Revision: 822034
- Update to first Bluez5 compatible version
- Switch to the git version due to rapid Bluez5 integration
- Remove deprecated obex-data-server from requires tag
- Restore blueman, has new maintainer team and supports bluez5
+ luigiwalser <luigiwalser>
- obsoleted by bluez due to incompatibility with bluez5

* Sun Sep 29 2013 fwang <fwang> 1.23-1.mga4
+ Revision: 489190
- cleanup spec
+ dams <dams>
- new version 1.23

* Fri Jan 11 2013 umeabot <umeabot> 1.21-7.mga3
+ Revision: 346924
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 01 2013 pterjan <pterjan> 1.21-6.mga3
+ Revision: 337448
- Fix for _libdir != _libexecdir

* Wed Oct 03 2012 malo <malo> 1.21-5.mga3
+ Revision: 302254
- update RPM group

* Sun Mar 20 2011 wally <wally> 1.21-4.mga1
+ Revision: 75039
- add cairo-devel BR
- drop buildroot definition
- drop old mdv scriptlets
- merge python parts into main package
- drop some runtime requires from buildrequires
- clean .spec
- imported package blueman


* Mon Nov 08 2010 Funda Wang <fwang@mandriva.org> 1.21-2mdv2011.0
+ Revision: 595015
- rebuild for py 2.7

* Sat Dec 26 2009 Emmanuel Andry <eandry@mandriva.org> 1.21-1mdv2010.1
+ Revision: 482499
- New version 1.21
- update BR
- update files list

* Wed Jul 29 2009 Eugeni Dodonov <eugeni@mandriva.com> 1.10-3mdv2010.0
+ Revision: 403707
- Bring back .so files to prevent blueman-* from crashing on startup.

* Sat Jul 25 2009 Emmanuel Andry <eandry@mandriva.org> 1.10-1mdv2010.0
+ Revision: 399801
- New version 1.10
- add source url
- update files list

* Fri Mar 27 2009 Emmanuel Andry <eandry@mandriva.org> 1.02-4mdv2009.1
+ Revision: 361574
- don't explicitely requires notification-daemon

* Mon Mar 02 2009 Emmanuel Andry <eandry@mandriva.org> 1.02-3mdv2009.1
+ Revision: 347587
- requires python-blueman

* Mon Mar 02 2009 Emmanuel Andry <eandry@mandriva.org> 1.02-2mdv2009.1
+ Revision: 347346
- fix files
- BR python-dbus
- fix BR
- BR python-devel
- import blueman


